@@ -176,7 +176,7 @@ def is_dev_repo(config):
 def slugify(s):
     slug = normalize('NFKD', s)
     slug = slug.encode('ascii', 'ignore').lower()
-    slug = re.sub(r'[^a-z0-9]+', '-', slug).strip('-')
+    slug = re.sub(r'[^a-z0-9]+', '-', slug.decode('ascii', 'ignore')).strip('-')
     return re.sub(r'[-]+', '-', slug)
 
 
